@@ -1,10 +1,7 @@
 # import asyncio
-import asyncio
-import os
-import threading
 import time
 # from ..Scheduler import IntervalTask
-from ..Scheduler import dbg, get_async_result, create_async_event
+from ..Scheduler import dbg, sql_clean_time
 from ..dbserver.asyncio_base import Base, ENGINE_DICT, mysql, can_return_directly
 
 
@@ -22,14 +19,14 @@ class async_data_manager(object):
             self.use_cache = self.t_data['cache']
         self.threading_pool = []
 
-        dbg('creating DB connection pool...')
-        # for i in range(0,self.min_keep_connection):
-        get_async_result(self.find_free_sql())
-        # create_async_event(self.new())
-        # while 1:
-        #     if len(self.threading_pool.keys()) != 0:
-        #         break
-        dbg('connect done!')
+        # dbg('creating DB connection pool...')
+        # # for i in range(0,self.min_keep_connection):
+        # # get_async_result(self.find_free_sql())
+        # # create_async_event(self.new())
+        # # while 1:
+        # #     if len(self.threading_pool.keys()) != 0:
+        # #         break
+        # dbg('connect done!')
         # IntervalTask(data_manager.keep_cycle, self.keep_connect)
         self.mem_cache = {}
 
@@ -60,7 +57,7 @@ class async_data_manager(object):
         need_kill_session = []
         for thread_id in range(0, len(self.threading_pool)):
             session_status = self.threading_pool[thread_id]
-            if int(time.time()) - session_status[1] < 45:
+            if int(time.time()) - session_status[1] < sql_clean_time:
                 session = session_status[0]
                 if session._is_busy != 1:
                     session.become_busy()
@@ -71,7 +68,6 @@ class async_data_manager(object):
 
         session = await self.create_new_sql()
         session.become_busy()
-        # self.add_new_sql(sql)
         self.threading_pool.append((session, int(time.time())))
 
         # mypid = str(os.getpid())
@@ -86,7 +82,6 @@ class async_data_manager(object):
     async def new(self):
         sql = await self.create_new_sql()
         # dbg(id(sql))
-        # self.add_new_sql(sql)
         return sql
 
     async def create_new_sql(self, ):
@@ -114,7 +109,7 @@ class async_data_manager(object):
         self.clean_table(table)
         return result
 
-    async def find(self, table, conditions, or_cond, fields=('*',), order=None, show_sql=False, from_cache=False,
+    async def find(self, table, conditions, or_cond=None, fields=('*',), order=None, show_sql=False, from_cache=False,
              for_update=False):
         sql = await self.find_free_sql()
         table = self.get_table_name(table)
@@ -140,7 +135,7 @@ class async_data_manager(object):
         # await sql.become_free()
         return result['result']
 
-    async def select(self, table, conditions, or_cond, fields=('*',), group=None, order=None, limit=None, show_sql=False,
+    async def select(self, table, conditions, or_cond=None, fields=('*',), group=None, order=None, limit=None, show_sql=False,
                from_cache=False, for_update=False):
         print('开始查询')
         sql = await self.find_free_sql()
@@ -166,7 +161,7 @@ class async_data_manager(object):
         # await sql.become_free()
         return result['result']
 
-    async def update(self, table, conditions, or_cond, params, show_sql=False):
+    async def update(self, table, conditions, or_cond=None, params=None, show_sql=False):
         sql = await self.find_free_sql()
         table = self.get_table_name(table)
         result = await sql.update(table, conditions, or_cond, params, show_sql)
@@ -174,7 +169,7 @@ class async_data_manager(object):
         await sql.become_free()
         return result
 
-    async def delete(self, table, conditions, or_cond, show_sql=False):
+    async def delete(self, table, conditions, or_cond=None, show_sql=False):
         sql = await self.find_free_sql()
         table = self.get_table_name(table)
         result = await sql.delete(table, conditions, or_cond, show_sql)
