@@ -144,9 +144,9 @@ class Data(object):
         if show_manager_id is True:
             dbg('本次任务通过', base_id, '执行')
         # dbg(params)
-        Data.Base_pool[base_id].update(table, conditions, or_cond, params,
+        return Data.Base_pool[base_id].update(table, conditions, or_cond, params,
                                        show_sql) if base_id in Data.Base_pool else None
-        return
+
 
     # update data
 
